package com.atguigu.spzx.manger.controller;

import com.atguigu.log.annotation.Log;
import com.atguigu.spzx.manger.service.ProductSpecService;
import com.atguigu.spzx.model.entity.product.ProductSpec;
import com.atguigu.spzx.model.vo.result.Result;
import com.github.pagehelper.PageInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "商品规格管理")
@RestController
@RequestMapping(value = "/admin/product/productSpec")
public class ProductSpecController {
    @Autowired
    private ProductSpecService productSpecService;

    @Log(title = "列表查询", businessType = 0)
    @Operation(summary = "列表查询", description = "列表查询")
    @GetMapping("{page}/{limit}")
    public Result<PageInfo<ProductSpec>> findByPage(@PathVariable Integer page, @PathVariable Integer limit) {
        PageInfo<ProductSpec> pageInfo = productSpecService.findByPage(page, limit);
        return Result.success(pageInfo);
    }

    @Log(title = "添加功能", businessType = 1)
    @Operation(summary = "添加功能", description = "添加功能")
    @PostMapping("save")
    public Result<ProductSpec> save(@RequestBody ProductSpec productSpec) {
        productSpecService.save(productSpec);
        return Result.success();
    }

    @Log(title = "修改功能", businessType = 2)
    @Operation(summary = "修改功能", description = "修改功能")
    @PutMapping("updateById")
    public Result<ProductSpec> updateById(@RequestBody ProductSpec productSpec) {
        productSpecService.updateById(productSpec);
        return Result.success();
    }

    @Log(title = "删除功能", businessType = 3)
    @Operation(summary = "删除功能", description = "删除功能")
    @DeleteMapping("deleteById/{id}")
    public Result<Long> removeById(@PathVariable Long id) {
        productSpecService.deleteById(id);
        return Result.success();
    }

    @Log(title = "加载商品规格数据", businessType = 0)
    @Operation(summary = "加载商品规格数据", description = "加载商品规格数据")
    @GetMapping("findAll")
    public Result<List<ProductSpec>> findAll() {
        List<ProductSpec> list = productSpecService.findAll();
        return Result.success(list);
    }
}